@@ -392,181 +392,17 @@ specplot <- function(sig, sr, t, start, end, tfrom0=TRUE, freqRange=c(0,5000),
   }
 
   if (pitch_plotOnSpec) {
-    pfr <- pitch_freqRange
-    if (tfrom0) pt$t <- pt$t - org_start
-    if (pitch_scale == 'logarithmic') {
-      pt$f <- log(pt$f)
-      pfr <- log(pitch_freqRange)
-    }
-    sRan <- freqRange[2] - freqRange[1]
-    pRan <- pfr[2] - pfr[1]
-    multiplier <- sRan / pRan
-    pt$f <- freqRange[1] + (pt$f - pfr[1]) * multiplier
-
-    if (!is.null(pitch_highlight)) {
-      highlight_tSpeckle <- c()
-      highlight_fSpeckle <- c()
-      highlight_tDraw <- c()
-      highlight_fDraw <- c()
-      for (int in 1:length(pitch_highlight$start)) {
-        times <- which(pt$t > pitch_highlight$start[int] &
-                         pt$t < pitch_highlight$end[int])
-        highlight_tSpeckle <- c(highlight_tSpeckle, pt$t[times],
-                                max(pt$t[times] + 0.0001))
-        highlight_fSpeckle <- c(highlight_fSpeckle, pt$f[times], NA)
-        if (pitch_highlight$start[int] < start) {
-          extrema <- zoo::na.approx(c(NA, pt$f),
-                                    c(pitch_highlight$end[int], pt$t))
-          highlight_tDraw <- c(highlight_tDraw,
-                               pt$t[times], pitch_highlight$end[int],
-                               max(pt$t[times] + 0.0001))
-          highlight_fDraw <- c(highlight_fDraw, pt$f[times], extrema[1], NA)
-        } else {
-          extrema <- zoo::na.approx(c(NA, NA, pt$f),
-                                    c(pitch_highlight$start[int],
-                                      pitch_highlight$end[int],
-                                      pt$t))[1:2]
-          highlight_tDraw <- c(highlight_tDraw, pitch_highlight$start[int],
-                               pt$t[times], pitch_highlight$end[int],
-                               max(pt$t[times] + 0.0001))
-          highlight_fDraw <- c(highlight_fDraw, extrema[1], pt$f[times],
-                               extrema[2], NA)
-        }
-      }
-
-      if (!'color' %in% names(pitch_highlight)) pitch_highlight$color <-
-        pitch_color
-      if (!'drawSize' %in% names(pitch_highlight)) pitch_highlight$drawSize <-
-        drawSize
-      if (!'speckleSize' %in% names(pitch_highlight)) {
-        pitch_highlight$speckleSize <- speckleSize
-      }
-    }
-
-    if ('draw' %in% pitch_plotType) {
-      if (length(pitch_color) == 2) graphics::lines(pt$t, pt$f, lwd=drawSize+2,
-                                                    col=pitch_color[2])
-      graphics::lines(pt$t, pt$f, lwd=drawSize, col=pitch_color[1])
-      if (!is.null(pitch_highlight)) {
-        if (length(pitch_highlight$color) == 2) {
-          graphics::lines(highlight_tDraw, highlight_fDraw,
-                          lwd=pitch_highlight$drawSize+2,
-                          col=pitch_highlight$color[2])
-        }
-        graphics::lines(highlight_tDraw, highlight_fDraw,
-                        col=pitch_highlight$color[1],
-                        lwd=pitch_highlight$drawSize)
-      }
-    }
-    if ('speckle' %in% pitch_plotType) {
-      if (length(pitch_color) == 2) graphics::points(pt$t, pt$f, lwd=3, pch=20,
-                                                     col=pitch_color[2],
-                                                     cex=speckleSize)
-      graphics::points(pt$t, pt$f, pch=20, col=pitch_color[1], cex=speckleSize)
-      if (!is.null(pitch_highlight)) {
-        if (length(pitch_highlight$color == 2)) {
-          graphics::points(highlight_tSpeckle, highlight_fSpeckle,
-                           lwd=3, pch=20,
-                           col=pitch_highlight$color[2],
-                           cex=pitch_highlight$speckleSize)
-        }
-        graphics::points(highlight_tSpeckle, highlight_fSpeckle, pch=20,
-                         col=pitch_highlight$color[1],
-                         cex=pitch_highlight$speckleSize)
-      }
-    }
-
-    pline <- c(3.5,1)
-    if (intensity_plotOnSpec) pline <- c(1,1)
-
-    graphics::mtext(pitch_axisLabel, side=4, line=pline[1], cex=0.8, las=3,
-                    col=pitch_color[1])
-
-    if (min_max_only[ind]) {
-      graphics::mtext(pitch_freqRange[1], side=4, line=pline[2],
-                      at=freqRange[1], padj=0, las=2, cex=0.7,
-                      col=pitch_color[1])
-      graphics::mtext(pitch_freqRange[2], side=4, line=pline[2],
-                      at=freqRange[2], padj=1, las=2, cex=0.7,
-                      col=pitch_color[1])
-    } else {
-      rtix <- pretty(pfr[1]:pfr[2])
-      graphics::axis(4, at=(rtix-pfr[1])*multiplier, labels=rtix,
-                     col.ticks=pitch_color[1], col.axis=pitch_color[1])
-    }
+    pitch_overlay(pt, freqRange[1], freqRange[2], start, org_start, tfrom0,
+                  pitch_freqRange, pitch_plotType, pitch_scale, pitch_color,
+                  ind, drawSize, speckleSize, pitch_axisLabel, min_max_only,
+                  pitch_highlight, intensity_plotOnSpec)
   }
 
   if (intensity_plotOnSpec) {
-    if (tfrom0) it$t <- it$t - org_start
-    sRan <- freqRange[2] - freqRange[1]
-    iRan <- intensity_range[2] - intensity_range[1]
-    multiplier <- sRan / iRan
-    it$i <- freqRange[1] + (it$i - intensity_range[1]) * multiplier
-
-    if (!is.null(intensity_highlight)) {
-      highlight_t <- c()
-      highlight_i <- c()
-      for (int in 1:length(intensity_highlight$start)) {
-        times <- which(it$t > intensity_highlight$start[int] &
-                         it$t < intensity_highlight$end[int])
-        if (intensity_highlight$start[int] < start) {
-          extrema <- zoo::na.approx(c(NA, it$i),
-                                    c(intensity_highlight$end[int], it$t))
-          highlight_t <- c(highlight_t,
-                           it$t[times], intensity_highlight$end[int],
-                           max(it$t[times] + 0.0001))
-          highlight_i <- c(highlight_i, it$i[times], extrema[1], NA)
-        } else {
-          extrema <- zoo::na.approx(c(NA, NA, it$i),
-                                    c(intensity_highlight$start[int],
-                                      intensity_highlight$end[int],
-                                      it$t))[1:2]
-          highlight_t <- c(highlight_t, intensity_highlight$start[int],
-                           it$t[times], intensity_highlight$end[int],
-                           max(it$t[times] + 0.0001))
-          highlight_i <- c(highlight_i, extrema[1], it$i[times], extrema[2], NA)
-        }
-      }
-      if (!'color' %in% names(intensity_highlight)) intensity_highlight$color <-
-        intensity_color
-      if (!'drawSize' %in% names(intensity_highlight)) {
-        intensity_highlight$drawSize <- drawSize
-      }
-    }
-
-    if (length(intensity_color) == 2) graphics::lines(it$t, it$i,
-                                                      lwd=drawSize+2,
-                                                      col=intensity_color[2])
-    graphics::lines(it$t, it$i, col=intensity_color[1], lwd=drawSize)
-    if (!is.null(intensity_highlight)) {
-      if (length(intensity_highlight$color) == 2) {
-        graphics::lines(highlight_t, highlight_i,
-                        lwd=intensity_highlight$drawSize+2,
-                        col=intensity_highlight$color[2])
-      }
-      graphics::lines(highlight_t, highlight_i,
-                      col=intensity_highlight$color,
-                      lwd=intensity_highlight$drawSize)
-    }
-
-    iline <- c(3.5,1)
-    if (pitch_plotOnSpec) iline <- c(3.5,3.5)
-
-    graphics::mtext(intensity_axisLabel, side=4, line=iline[1], cex=0.8, las=3,
-                    col=intensity_color[1])
-
-    if (min_max_only[ind]) {
-      graphics::mtext(round(intensity_range[1], 0),
-                      side=4, line=iline[2], at=freqRange[1],
-                      padj=0, las=2, cex=0.7, col=intensity_color[1])
-      graphics::mtext(round(intensity_range[2]),
-                      side=4, line=iline[2], at=freqRange[2],
-                      padj=1, las=2, cex=0.7, col=intensity_color[1])
-    } else {
-      rtix <- pretty(intensity_range[1]:intensity_range[2])
-      graphics::axis(4, at=(rtix-intensity_range[1])*multiplier, labels=rtix,
-                     col.ticks=intensity_color[1], col.axis=intensity_color[1])
-    }
+    intensity_overlay(it, freqRange[1], freqRange[2], start, org_start,
+                      tfrom0, intensity_range, intensity_color, ind, drawSize,
+                      intensity_axisLabel, min_max_only, intensity_highlight,
+                      pitch_plotOnSpec)
   }
 
   if (tgbool) {
